using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace IrisSetting
{
    public class ConfigModel
    {
        private String formType;
        private String motherboardType;
        private String language;
        private String tempType;
        private String rejectTimeOut;
        private String showTimeSuccess;
        private String showTimeFailure;
        private DoorConfig doorConfig = new DoorConfig();
        private PrintConfig printConfig = new PrintConfig();
        private WorkConfig workConfig = new WorkConfig();
        
        public string FormType
        {
            get
            {
                return formType;
            }

            set
            {
                formType = value;
            }
        }

        public string MotherboardType
        {
            get
            {
                return motherboardType;
            }

            set
            {
                motherboardType = value;
            }
        }

        public string Language
        {
            get
            {
                return language;
            }

            set
            {
                language = value;
            }
        }

        public string RejectTimeOut
        {
            get
            {
                return rejectTimeOut;
            }

            set
            {
                rejectTimeOut = value;
            }
        }

        public string ShowTimeSuccess
        {
            get
            {
                return showTimeSuccess;
            }

            set
            {
                showTimeSuccess = value;
            }
        }

        public string ShowTimeFailure
        {
            get
            {
                return showTimeFailure;
            }

            set
            {
                showTimeFailure = value;
            }
        }

        public DoorConfig DoorConfig
        {
            get
            {
                return doorConfig;
            }

            set
            {
                doorConfig = value;
            }
        }

        public PrintConfig PrintConfig
        {
            get
            {
                return printConfig;
            }

            set
            {
                printConfig = value;
            }
        }

        public WorkConfig WorkConfig
        {
            get
            {
                return workConfig;
            }

            set
            {
                workConfig = value;
            }
        }

        public string TempType
        {
            get
            {
                return tempType;
            }

            set
            {
                tempType = value;
            }
        }
    }

    public class DoorConfig
    {
        private String doorSystemEnable;
        private String needPermisson;
        private String serialPort;
        private String sleepTime;
        private String checkTemp;

        public string DoorSystemEnable
        {
            get
            {
                return doorSystemEnable;
            }

            set
            {
                doorSystemEnable = value;
            }
        }

        public string NeedPermisson
        {
            get
            {
                return needPermisson;
            }

            set
            {
                needPermisson = value;
            }
        }

        public string SerialPort
        {
            get
            {
                return serialPort;
            }

            set
            {
                serialPort = value;
            }
        }

        public string SleepTime
        {
            get
            {
                return sleepTime;
            }

            set
            {
                sleepTime = value;
            }
        }

        public string CheckTemp
        {
            get
            {
                return checkTemp;
            }

            set
            {
                checkTemp = value;
            }
        }
    }

    public class PrintConfig
    {
        private String printEnable;
        private String deviceSN;
        private String destIp;
        private String destPort;

        public string PrintEnable
        {
            get
            {
                return printEnable;
            }

            set
            {
                printEnable = value;
            }
        }

        public string DeviceSN
        {
            get
            {
                return deviceSN;
            }

            set
            {
                deviceSN = value;
            }
        }

        public string DestIp
        {
            get
            {
                return destIp;
            }

            set
            {
                destIp = value;
            }
        }

        public string DestPort
        {
            get
            {
                return destPort;
            }

            set
            {
                destPort = value;
            }
        }
    }

    public class DbConfig
    {
        private String sqlType;

        private String localDatabaseName;
        private String localDatabasePort;
        private String localDatabaseUser;
        private String localDatabasePassword;

        private String serverIp;
        private String serverDatabaseName;
        private String serverDatabasePort;
        private String serverDatabaseUser;
        private String serverDatabasePassword;

        private String serverAppPort;
        private String listenPort;
        private String tmpPath;

        public string SqlType
        {
            get
            {
                return sqlType;
            }

            set
            {
                sqlType = value;
            }
        }

        public string LocalDatabaseName
        {
            get
            {
                return localDatabaseName;
            }

            set
            {
                localDatabaseName = value;
            }
        }

        public string LocalDatabasePort
        {
            get
            {
                return localDatabasePort;
            }

            set
            {
                localDatabasePort = value;
            }
        }

        public string LocalDatabaseUser
        {
            get
            {
                return localDatabaseUser;
            }

            set
            {
                localDatabaseUser = value;
            }
        }

        public string LocalDatabasePassword
        {
            get
            {
                return localDatabasePassword;
            }

            set
            {
                localDatabasePassword = value;
            }
        }

        public string ServerIp
        {
            get
            {
                return serverIp;
            }

            set
            {
                serverIp = value;
            }
        }

        public string ServerDatabaseName
        {
            get
            {
                return serverDatabaseName;
            }

            set
            {
                serverDatabaseName = value;
            }
        }

        public string ServerDatabasePort
        {
            get
            {
                return serverDatabasePort;
            }

            set
            {
                serverDatabasePort = value;
            }
        }

        public string ServerDatabaseUser
        {
            get
            {
                return serverDatabaseUser;
            }

            set
            {
                serverDatabaseUser = value;
            }
        }

        public string ServerDatabasePassword
        {
            get
            {
                return serverDatabasePassword;
            }

            set
            {
                serverDatabasePassword = value;
            }
        }

        public string ServerAppPort
        {
            get
            {
                return serverAppPort;
            }

            set
            {
                serverAppPort = value;
            }
        }

        public string ListenPort
        {
            get
            {
                return listenPort;
            }

            set
            {
                listenPort = value;
            }
        }

        public string TmpPath
        {
            get
            {
                return tmpPath;
            }

            set
            {
                tmpPath = value;
            }
        }
    }

    public class TempConfig
    {
        private string tempEnable;
        private string correction;

        private string paramRegion0;
        private string paramRegion11;
        private string paramRegion12;

        private string separate0;
        private string separate1;
        private string separate2;
        private string separate3;

        private string paramRegion21;
        private string paramRegion22;
        private string paramRegion31;
        private string paramRegion32;

        private string paramHigh;
        private string tnor;
        private string tabnor;

        public string Correction
        {
            get
            {
                return correction;
            }

            set
            {
                correction = value;
            }
        }

        public string ParamRegion0
        {
            get
            {
                return paramRegion0;
            }

            set
            {
                paramRegion0 = value;
            }
        }

        public string ParamRegion11
        {
            get
            {
                return paramRegion11;
            }

            set
            {
                paramRegion11 = value;
            }
        }

        public string ParamRegion12
        {
            get
            {
                return paramRegion12;
            }

            set
            {
                paramRegion12 = value;
            }
        }

        public string Separate0
        {
            get
            {
                return separate0;
            }

            set
            {
                separate0 = value;
            }
        }

        public string Separate1
        {
            get
            {
                return separate1;
            }

            set
            {
                separate1 = value;
            }
        }

        public string Separate2
        {
            get
            {
                return separate2;
            }

            set
            {
                separate2 = value;
            }
        }

        public string Separate3
        {
            get
            {
                return separate3;
            }

            set
            {
                separate3 = value;
            }
        }

        public string ParamRegion21
        {
            get
            {
                return paramRegion21;
            }

            set
            {
                paramRegion21 = value;
            }
        }

        public string ParamRegion22
        {
            get
            {
                return paramRegion22;
            }

            set
            {
                paramRegion22 = value;
            }
        }

        public string ParamRegion31
        {
            get
            {
                return paramRegion31;
            }

            set
            {
                paramRegion31 = value;
            }
        }

        public string ParamHigh
        {
            get
            {
                return paramHigh;
            }

            set
            {
                paramHigh = value;
            }
        }

        public string Tnor
        {
            get
            {
                return tnor;
            }

            set
            {
                tnor = value;
            }
        }

        public string Tabnor
        {
            get
            {
                return tabnor;
            }

            set
            {
                tabnor = value;
            }
        }

        public string ParamRegion32
        {
            get
            {
                return paramRegion32;
            }

            set
            {
                paramRegion32 = value;
            }
        }

        public string TempEnable
        {
            get
            {
                return tempEnable;
            }

            set
            {
                tempEnable = value;
            }
        }
    }
    
    public class WorkConfig
    {
        private string workEnable;

        public string WorkEnable
        {
            get
            {
                return workEnable;
            }

            set
            {
                workEnable = value;
            }
        }

    }
}